#ifndef NT2_INCLUDE_FUNCTIONS_BITWISE_SELECT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BITWISE_SELECT_HPP_INCLUDED

#include <nt2/bitwise/include/functions/bitwise_select.hpp>

#endif
